@@ -15,7 +15,7 @@ test_that("nhd_plus_get fails well", {
 
 test_that("remote urls are constructed correctly", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
 
   expect_true(
     crul::ok(
